
Data sources
============

These data are not intended to represent a real energy system and are included for illustrative purposes only.


``csp_resource.csv``
--------------------

All three time series give heat output in kW per m2 solar field, based on free 2005 DNI data from `HelioClim <http://www.soda-is.com/eng/helioclim/index.html>`_ (HC3v2), processed with the CSP plant model described by [#gauche]_.


``demand-1.csv`` and ``demand-2.csv``
-------------------------------------

Both time series are based on modified data from the IIASA GAINS model database [#gains]_.


References
----------

.. [#gauche] Gauché, P., von Backström, T.W. & Brent, A.C., 2011. CSP Modeling Methodology for Macro Decision Making - Emphasis on the Central Receiver Type. In Granada, Spain.

.. [#gains] Amann, M., et al., Cost-effective control of air quality and greenhouse gases in Europe: Modeling and policy applications. Environmental Modelling & Software, 2011. 26(12): p. 1489-1501.
